@@ -291,7 +291,7 @@ class MarketAnalyzer:
         """
         return self.base * self.df / self.df.iloc[0, :].values
 
-    def plot_perf(self, title='Performances', ax=None, show=True,saving_png_path = None, **kwargs):
+    def plot_perf(self, title='Performances', ax=None, show=True,saving_png_path = None,saving_png_perf_path = None, **kwargs):
         """ Plot asset performances.
 
         Parameters
@@ -315,6 +315,10 @@ class MarketAnalyzer:
 
         if not df.empty:
             df.plot(ax=ax, title=title, **kwargs)
+            if saving_png_perf_path is not None:
+                fig = ax.get_figure()
+                fig.savefig(saving_png_perf_path)
+
 
         if show:
             plt.show()
