@@ -69,33 +69,78 @@ def generate_lo_slope_ma(lookback_windows, pente_windows, contravariants,):
     return parameters
 
 
-def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,dec_levels):
+# def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,dec_levels,thresholds,obs_covs):
+#     parameters = []
+#     for lookback_window in lookback_windows:
+#         for contravariant in contravariants:
+#             for fft_filter_type in fft_filter_types:
+#                 for n_harm in n_harms:
+#                     for dec_level in dec_levels:
+#                         for threshold in thresholds:
+#                             for observation_covariance in obs_covs:
+#                                 if n_harm < lookback_window:
+#                                     parameters.append({
+#                                         'lookback_window':lookback_window,
+#                                         'contravariant':contravariant,
+#                                         'fft_filter_type':fft_filter_type,
+#                                         'n_harm':n_harm,
+#                                         'dec_level':dec_level,
+#                                         'threshold':threshold,
+#                                         'observation_covariance':observation_covariance
+#                                     })
+#     return parameters
+
+def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,dec_levels,thresholds):
     parameters = []
     for lookback_window in lookback_windows:
         for contravariant in contravariants:
-            for n_harm in n_harms:
-                for dec_level in dec_levels:
-                    if n_harm < lookback_window:
-                        parameters.append({
-                            'lookback_window':lookback_window,
-                            'contravariant':contravariant,
-                            'n_harm':n_harm,
-                            'dec_level':dec_level
-                        })
+            for fft_filter_type in fft_filter_types:
+                for n_harm in n_harms:
+                    for dec_level in dec_levels:
+                        for threshold in thresholds:
+                                if n_harm < lookback_window:
+                                    parameters.append({
+                                        'lookback_window':lookback_window,
+                                        'contravariant':contravariant,
+                                        'fft_filter_type':fft_filter_type,
+                                        'n_harm':n_harm,
+                                        'dec_level':dec_level,
+                                        'threshold':threshold,
+                                    })
     return parameters
 
-
-def generate_fourier_decomposition(lookback_windows,contravariants,n_harms):
+def generate_kalman(lookback_windows,contravariants,n_harms,fft_filter_types,thresholds,obs_covs):
     parameters = []
     for lookback_window in lookback_windows:
         for contravariant in contravariants:
-            for n_harm in n_harms:
-                if n_harm<lookback_window:
-                    parameters.append({
-                        'lookback_window':lookback_window,
-                        'contravariant':contravariant,
-                        'n_harm':n_harm
-                    })
+            for fft_filter_type in fft_filter_types:
+                for n_harm in n_harms:
+                    for threshold in thresholds:
+                        for observation_covariance in obs_covs:
+                            if n_harm < lookback_window:
+                                parameters.append({
+                                    'lookback_window':lookback_window,
+                                    'contravariant':contravariant,
+                                    'fft_filter_type':fft_filter_type,
+                                    'n_harm':n_harm,
+                                    'threshold':threshold,
+                                    'observation_covariance':observation_covariance
+                                })
+    return parameters
+
+def generate_fourier_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for contravariant in contravariants:
+            for fft_filter_type in fft_filter_types:
+                for n_harm in n_harms:
+                    if n_harm<lookback_window:
+                        parameters.append({
+                            'lookback_window':lookback_window,
+                            'fft_filter_type': fft_filter_type,
+                            'contravariant':contravariant,
+                            'n_harm':n_harm
+                        })
     return parameters
 
 def generate_lookback_contravariant(lookback_windows, contravariants):
@@ -108,6 +153,18 @@ def generate_lookback_contravariant(lookback_windows, contravariants):
             })
     return parameters
 
+def generate_alpha_5(lookback_windows, lags, contravariants):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for lag in lags:
+            for contravariant in contravariants:
+                if lag < int(lookback_window/2):
+                    parameters.append({
+                        'lookback_window':lookback_window,
+                        'lag':lag,
+                        'contravariant':contravariant
+                    })
+    return parameters
 
 def generate_alpha_8(lookback_windows, contravariants, lags):
     parameters = []
@@ -122,6 +179,51 @@ def generate_alpha_8(lookback_windows, contravariants, lags):
                     })
     return parameters
 
+
+def generate_alpha_16(lookback_windows, contravariants, lags):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for lag in lags:
+            for contravariant in contravariants:
+                if lag <= lookback_window/4 and lag >= 2:
+                    parameters.append({
+                        'lookback_window':lookback_window,
+                        'lag' : lag,
+                        'contravariant':contravariant
+                    })
+    return parameters
+
+def generate_alpha_16_lo(lookback_windows, contravariants, lags, up_thresholds):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for up_threshold in up_thresholds:
+            for lag in lags:
+                for contravariant in contravariants:
+                    if lag <= lookback_window/4 and lag >= 2:
+                        parameters.append({
+                            'lookback_window':lookback_window,
+                            'lag' : lag,
+                            'up_threshold': up_threshold,
+                            'contravariant':contravariant
+                        })
+    return parameters
+
+def generate_alpha_16_ls(lookback_windows, contravariants, lags, up_thresholds, low_thresholds):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for up_threshold in up_thresholds:
+            for low_threshold in low_thresholds:
+                for lag in lags:
+                    for contravariant in contravariants:
+                        if lag <= lookback_window/4 and lag >= 2:
+                            parameters.append({
+                                'lookback_window':lookback_window,
+                                'lag' : lag,
+                                'low_threshold': low_threshold,
+                                'up_threshold': up_threshold,
+                                'contravariant':contravariant
+                            })
+    return parameters
 def generate_volume_weighted_high_low_vol_lo(lookback_windows, vol_thresholds, up_trend_thresholds, contravariants, lags, display):
     parameters = []
     for lookback_window in lookback_windows:
